GraphicalReportHandler

Struct GraphicalReportHandler 

pub struct GraphicalReportHandler { /* private fields */ }
A ReportHandler that displays a given Report in a quasi-graphical way, using terminal colors, unicode drawing characters, and other such things.

This is the default reporter bundled with miette.

This printer can be customized by using new_themed() and handing it a GraphicalTheme of your own creation (or using one of its own defaults!)

See set_hook() for more details on customizing your global printer.

Implementations



impl GraphicalReportHandler

pub fn new() -> GraphicalReportHandler

Create a new GraphicalReportHandler with the default GraphicalTheme. This will use both unicode characters and colors.

pub fn new_themed(theme: GraphicalTheme) -> GraphicalReportHandler

Create a new GraphicalReportHandler with a given GraphicalTheme.

pub fn tab_width(self, width: usize) -> GraphicalReportHandler

Set the displayed tab width in spaces.

Whether to enable error code linkification using Diagnostic::url().

pub fn with_cause_chain(self) -> GraphicalReportHandler

Include the cause chain of the top-level error in the graphical output, if available.

pub fn without_cause_chain(self) -> GraphicalReportHandler

Do not include the cause chain of the top-level error in the graphical output.

pub fn with_urls(self, urls: bool) -> GraphicalReportHandler

Whether to include Diagnostic::url() in the output.

Disabling this is not recommended, but can be useful for more easily reproducible tests, as url(docsrs) links are version-dependent.

pub fn with_theme(self, theme: GraphicalTheme) -> GraphicalReportHandler

Set a theme for this handler.

pub fn with_width(self, width: usize) -> GraphicalReportHandler

Sets the width to wrap the report at.

pub fn with_wrap_lines(self, wrap_lines: bool) -> GraphicalReportHandler

Enables or disables wrapping of lines to fit the width.

pub fn with_break_words(self, break_words: bool) -> GraphicalReportHandler

Enables or disables breaking of words during wrapping.

pub fn with_word_separator( self, word_separator: WordSeparator, ) -> GraphicalReportHandler

Sets the word separator to use when wrapping.

pub fn with_word_splitter( self, word_splitter: WordSplitter, ) -> GraphicalReportHandler

Sets the word splitter to usewhen wrapping.

Sets the ‘global’ footer for this handler.

pub fn with_context_lines(self, lines: usize) -> GraphicalReportHandler

Sets the number of lines of context to show around each error.

pub fn with_syntax_highlighting( self, highlighter: impl Highlighter + Send + Sync + 'static, ) -> GraphicalReportHandler

Enable syntax highlighting for source code snippets, using the given [Highlighter]. See the [crate::highlighters] crate for more details.

pub fn without_syntax_highlighting(self) -> GraphicalReportHandler

Disable syntax highlighting. This uses the [crate::highlighters::BlankHighlighter] as a no-op highlighter.

Sets the display text for links. Miette displays (link) if this option is not set.



impl GraphicalReportHandler

pub fn render_report( &self, f: &mut impl Write, diagnostic: &dyn Diagnostic, ) -> Result<(), Error>

Render a Diagnostic. This function is mostly internal and meant to be called by the toplevel ReportHandler handler, but is made public to make it easier (possible) to test in isolation from global state.