Struct NarratableReportHandler
pub struct NarratableReportHandler { /* private fields */ }Expand description
ReportHandler that renders plain text and avoids extraneous graphics.
It’s optimized for screen readers and braille users, but is also used in any
non-graphical environments, such as non-TTY output.
Implementations
impl NarratableReportHandler
impl NarratableReportHandler
pub const fn new() -> NarratableReportHandler
pub const fn new() -> NarratableReportHandler
Create a new NarratableReportHandler. There are no customization
options.
pub const fn with_cause_chain(self) -> NarratableReportHandler
pub const fn with_cause_chain(self) -> NarratableReportHandler
Include the cause chain of the top-level error in the report, if available.
pub const fn without_cause_chain(self) -> NarratableReportHandler
pub const fn without_cause_chain(self) -> NarratableReportHandler
Do not include the cause chain of the top-level error in the report.
Set the footer to be displayed at the end of the report.
pub const fn with_context_lines(self, lines: usize) -> NarratableReportHandler
pub const fn with_context_lines(self, lines: usize) -> NarratableReportHandler
Sets the number of lines of context to show around each error.
impl NarratableReportHandler
impl NarratableReportHandler
pub fn render_report(
&self,
f: &mut impl Write,
diagnostic: &dyn Diagnostic,
) -> Result<(), Error>
pub fn render_report( &self, f: &mut impl Write, diagnostic: &dyn Diagnostic, ) -> Result<(), Error>
Render a Diagnostic. This function is mostly internal and meant to
be called by the toplevel ReportHandler handler, but is
made public to make it easier (possible) to test in isolation from
global state.