pub struct Label { /* private fields */ }Expand description
Represents a diagnostic label.
A label is a source span and optional diagnostic text that should be laid out next to the source snippet.
Implementations
Sourceimpl Label
impl Label
Sourcepub fn at<R>(range: R) -> Self
pub fn at<R>(range: R) -> Self
Construct a label for the given range of bytes, expressible as any type which can be
converted to a Range<usize>, e.g. [miette::SourceSpan].
Sourcepub fn point<L>(at: usize, label: L) -> Self
pub fn point<L>(at: usize, label: L) -> Self
Construct a label which points to a specific offset in the source file.