pub struct RelatedLabel {
pub severity: Severity,
pub message: Cow<'static, str>,
pub labels: Vec<Label>,
pub help: Option<Cow<'static, str>>,
pub file: Option<Arc<SourceFile>>,
}Expand description
This type is used to associate a more complex label or set of labels with some other error.
In particular, it is used to reference related bits of source code distinct from that of the original error. A related label can have a distinct severity, its own message, and its own sub-labels, and may reference code in a completely different source file that the original error.
Fields
severity: SeverityThe severity for this related label
message: Cow<'static, str>The message for this label
labels: Vec<Label>The sub-labels for this label
help: Option<Cow<'static, str>>If provided as a standalone diagnostic, the help message to provide
file: Option<Arc<SourceFile>>The source file to use when rendering source spans of this label as snippets.
Implementations
Sourceimpl RelatedLabel
impl RelatedLabel
pub fn new<S>(severity: Severity, message: S) -> Self
pub fn error<S>(message: S) -> Self
pub fn warning<S>(message: S) -> Self
pub fn advice<S>(message: S) -> Self
pub fn with_source_file(self, file: Option<Arc<SourceFile>>) -> Self
pub fn with_labeled_span<S>(self, span: SourceSpan, message: S) -> Self
pub fn with_label(self, label: Label) -> Self
pub fn with_labels<I>(self, labels: I) -> Selfwhere
I: IntoIterator<Item = Label>,
pub fn with_help<S>(self, help: S) -> Self